/****
*     oStatus.prg
*     (c) 1998 Manos Aspradakis
*
*     Displays and updates a status message to inform the user that a
*     process is executing.
*
*     Uses predefined or user defined frame sequences to display progress.
*     See oStatus.ch for some predefined progress indicators.
*
*/

#include "oobject.ch"
#include "oStatus.ch"

#ifdef TEST

Proc Test( nCharSet )
Local nKey, oStat1, oStat2, oStat3

    __xSaveScreen()

    SetColor( "n/bg" ) ; Scroll() ; SetCursor(0)

    oStat1    := Status():New( 10, 30, "GR+/B", 1 )
    oStat2    := Status():New( 12, 30, "GR+/B", 2 )
    oStat3    := Status():New( 14, 30, "GR+/B", 3 )

    DispOutAt( 1,0,PadC( "  oStatus() Demonstration  ", 80, "" ), "w+/bg" )
    DispOutAt( MaxRow()-1,0,PadC( "  Press ESCape to Exit  ", 80, "" ), "w+/bg")

    While .T.
        nKey := Inkey( .05 )
        if nKey == 27
           EXIT
        Endif

        oStat1:Update() ; oStat2:Update() ; oStat3:Update()

    END

    __xRestScreen()

RETURN

#endif

//

CLASS Status

DATA aCharSet     AS NIL
DATA nCharSet     AS 1
DATA FramesLen    AS 0
DATA Row, Col     AS 0
DATA Color        AS "W/N"
DATA Current      AS 1
DATA aFrames      AS { CHAR_SET_1,;
                       CHAR_SET_2,;
                       CHAR_SET_3 }

METHOD New( nRow, nCol, cColor, nCharSet, aCharSet )
METHOD Update()

ENDCLASS


//

METHOD New( nRow, nCol, cColor, nCharSet, aCharSet )

DEFAULT nCharSet := 1
DEFAULT cColor   := "W/N"

::Row    := nRow
::Col    := nCol
::Color  := cColor

// Create custom CharSet
IF aCharSet != NIL
   ::aCharSet := aCharSet
ENDIF

// Otherwise get predefined
IF nCharSet <= 3 .and. ::aCharSet == NIL
   ::aCharSet := ::aFrames[ nCharSet ]
ENDIF

::FramesLen := LEN( ::aCharSet )

RETURN self


//

METHOD Update( aStat )

   ::Current++

   IF ::Current > ::FramesLen
      ::Current := 1
   ENDIF

   DispBegin()

   DispOutAt( ::Row, ::Col,;
              ::aCharSet[::Current],;
              ::Color )

   DispEnd()

RETURN( self )

